kss_prevent_bubbling
open | /demo/kss_evt_preventbubbling.html |
assertText | logger |
clickAt | parent-node |
assertText | logger | containing DIV.
clickAt | log-reset |
assertText | logger |
clickAt | bubbling-node |
assertText | logger | bubbling P. containing DIV.
clickAt | log-reset |
assertText | logger |
clickAt | not-bubbling-node |
assertText | logger | not bubbling P.
clickAt | log-reset |
assertText | logger |